*Master Analysis file for SEAR paper;

#delimit;
clear;
clear mata;
clear matrix;
set more off;
set maxvar 30000;

local date="28feb18";

global version="eilin";
global version="shilpa";
global version="jon home";
global version="jon work";


if "${version}"=="eilin" {;
	global cleaned_data_dir "/Users/eilinlizfrancis/Dropbox/Fertilizer ROSCA project/Summer15_data/Data/";
	global results "/Users/eilinlizfrancis/Dropbox/Fertilizer ROSCA project/Summer15_data/Results/";
	};
	
if "${version}"=="shilpa" {;
	global cleaned_data_dir "C:\Users\20088\Dropbox\Fertilizer ROSCA project\Summer15_data\Data\";
	global results "C:\Users\20088\Dropbox\Fertilizer ROSCA project\Summer15_data\Results\";
	};
	
if "${version}"=="jon home" {;
	global cleaned_data_dir "C:\Users\jmrtw\Dropbox\SEAR\Summer15_data\Data\";
	global results "C:\Users\jmrtw\Dropbox\SEAR\Summer15_data\Results\";
	};

if "${version}"=="jon work" {;
	global cleaned_data_dir "C:\Users\jmrtwo\Dropbox\SEAR\Summer15_data\Data\";
	global results "C:\Users\jmrtwo\Dropbox\SEAR\Summer15_data\Results\";
	};

*************************************;
*************************************;
****Data manipulation;
*************************************;
*************************************;

*Generate indicator for early sales;
use "${cleaned_data_dir}\sales_module_FINAL", clear;

gen early_sale=0;
replace early_sale =1 if year_sale==2015 & (month_sale==9 | month_sale==8);
gen late_sale=0 if early_sale;
replace late_sale=1 if late_sale==.;

keep resp_id early_sale late_sale;
sort resp_id;

bys resp_id: egen early_sale_ind=max(early_sale) ;
bys resp_id: egen late_sale_ind=max(late_sale);

sort resp_id;
drop if resp_id==resp_id[_n-1];
drop early_sale late_sale;

merge 1:1 resp_id using "${cleaned_data_dir}\SEAR_analysis_working_`date'", nogen;

save "${cleaned_data_dir}\SEAR_analysis_working_merged", replace;



*************************************;
*************************************;
****Figures;
*************************************;
*************************************;

******************;
*Figure 1. Price Figure ;
******************;
use "${cleaned_data_dir}\prices_by_month", clear;

graph twoway
 (scatter sale_prices_observed month , connect(l) msymbol(x))
 (scatter expected_price_baseline month , connect(l) lpattern(-) msymbol(t))
 (scatter prices_retail month , connect(l) lpattern(.) msymbol(s)),
 xlabel(1 "8-2015" 2 "9-2015" 3 "10-2015" 4 "11-2015" 5 "12-2015" 
 6 "1-2016" 7 "2-2016" 8 "3-2016" 9 "4-2016" 10 "5-2016" 11 "6-2016" 12 "7-2016" 13 "8-2016" , angle(90))
 ylabel(1 (.1) 2, angle(0)) 
 xtitle("Month") ytitle("Price (normalized relative to Aug 2015)") saving("${results}\prices_augmented", replace) 
 title("Observed and Expected Prices, 2015-16", size(medium))
 xline(1, lcolor(black)) xline(6, lcolor(black)) xline(13, lcolor(black)) graphregion(color(white)) 
 legend(order(1 "Observed (Sales data)" 2 "Expected (Baseline survey)" 3 "Retail price (shops)") rows(3));
 


******************;
*Figure 2. CDF of deposits;
******************;
use "${cleaned_data_dir}\SEAR_analysis_working_`date'", clear;

sum logs_GSRA_total_dep_kg if gsra==1, d;
local _99=r(p99);


cumul logs_GSRA_total_dep_kg if gsra==1, gen(cdf);
twoway 
 (scatter cdf logs_GSRA_total_dep_kg if gsra==1 & logs_GSRA_total_dep_kg<`_99', msymbol(x) mcolor(maroon) yaxis(1)),
 ytitle("Percentage at or below") xtitle("Kilograms of maize deposited in GSRA")
 xlabel(0 (10) 150, angle(90)) xtick(0 (5) 150);
drop cdf;

gen logs_ISRA_total_dep_USD=logs_ISRA_total_dep/100;

sum logs_ISRA_total_dep_USD if isra==1, d;
cumul logs_ISRA_total_dep_USD if isra==1, gen(cdf);

twoway 
 (scatter cdf logs_ISRA_total_dep_USD if isra==1  , msymbol(x) mcolor(maroon) yaxis(1)),
 ytitle("Percentage at or below") xtitle("Amount deposited in ISRA (USD)")
 xlabel(0 (5) 50, angle(90)) xtick(0 (1) 50) saving("${results}\isra_cdf", replace);


******************;
*Figure 3.  Timing of maize sales;
******************;
use "${cleaned_data_dir}\sales_module_FINAL", clear;


gen month_sale_post_harvest=.;
replace month_sale_post_harvest=month_sale-7 if month_sale>=8 & month_sale<=12 & year_sale==2015;
replace month_sale_post_harvest=month_sale+5 if month_sale>=1 & month_sale<=8 & year_sale==2016;

collapse (mean) quantity month_sale year_sale, by(gsra month_sale_post_harvest);

graph twoway
 (scatter quantity month_sale_post_harvest if gsra==1 , connect(l))
 (scatter quantity month_sale_post_harvest if gsra==0 , connect(l) lpattern(-) msymbol(t)),
 xlabel(1 "8-2015" 2 "9-2015" 3 "10-2015" 4 "11-2015" 5 "12-2015" 
 6 "1-2016" 7 "2-2016" 8 "3-2016" 9 "4-2016" 10 "5-2016" 11 "6-2016" 12 "7-2016" 13 "8-2016" , angle(90))
 xtitle("Month") ytitle("Average sales") saving("${results}\timing", replace) 
 title("Timing of sales, 2015-16", size(medium))
 xline(1) xline(6) xline(13) graphregion(color(white)) 
 legend(order(1 "GSRA" 2 "non-GSRA") rows(2));

 
**********************;
*Web Appendix Figure A3: Capacity;
**********************;
use "${cleaned_data_dir}\logbook_ledger", replace;

keep if rosca_id != rosca_id[_n-1] & gsra==1;
cumul rosca_total_deposit_w5 , gen(cdf);

twoway 
 (scatter cdf rosca_total_deposit_w5 , msymbol(x) mcolor(maroon) yaxis(1)),
 ytitle("Percentage at or below") xtitle("Kilograms of maize stored in GSRA")
 xlabel(160 (100) 1660, angle(90)) xline(360) title("Net Amount Stored by GSRA ROSCAs", size(medium)) saving("${results}\capacity", replace) ;

**********************;
*Web Appendix Figure A4: Timing of deposits
**********************;
*Timing Figure;
use "${cleaned_data_dir}\logbook_ledger", clear;
keep resp_id gsra isra deposit_*;
reshape long deposit_amount_ deposit_date_, i(resp_id) j(dep_num);
drop if deposit_date_==. | deposit_amount_==.;

gen month=month(deposit_date);
gen year=year(deposit_date);

sort year month;
egen group=group(year month);


collapse (sum) deposit_amount_, by(group gsra isra);
gen deposit_amount_USD=deposit_amount_/100 if isra==1;

twoway bar deposit_amount_ group if gsra==1 & group<12, saving("${results}\GSRA deposits", replace) ytitle(Quantity deposited (kilograms)) xtitle(Month)
 title("GSRA Deposits by Month", size(medium)) xlabel(1 "8-2015" 2 "9-2015" 3 "10-2015" 4 "11-2015" 5 "12-2015" 
 6 "1-2016" 7 "2-2016" 8 "3-2016" 9 "4-2016" 10 "5-2016" 11 "6-2016", angle(90)) ;

 twoway bar deposit_amount_USD group if isra==1 & group<12, saving("${results}\ISRA deposits", replace) ytitle(Amount deposited (USD)) xtitle(Month)
 title("ISRA Deposits by Month", size(medium)) xlabel(1 "8-2015" 2 "9-2015" 3 "10-2015" 4 "11-2015" 5 "12-2015" 
 6 "1-2016" 7 "2-2016" 8 "3-2016" 9 "4-2016" 10 "5-2016" 11 "6-2016", angle(90)) ;


************************************;
*************************************;
****Tables;
*************************************;
*************************************;

******************;
*Web Appendix Table A1. ROSCA compliance;
******************;
use "${cleaned_data_dir}\ROSCA_compliance_FINAL", replace;

tab rosca_treatment;

tab rosca_traced;
tab rosca_treatment if rosca_traced==1;

count if rosca_traced==1 & rosca_duplicate==0;
tab rosca_treatment if rosca_traced==1 & rosca_duplicate==0;

tab rosca_has_baseline if rosca_traced==1 & rosca_duplicate==0;

tab rosca_treatment if rosca_traced==1;
tab rosca_treatment if rosca_has_baseline==1 & rosca_has_endline==1;


*Compliance;
reg rosca_traced gsra isra ;
sum rosca_traced if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) replace bdec(2) nocons 
 addstat("sample = all", 1, "control mean", `control_mean');

reg rosca_traced gsra isra if rosca_duplicate==0;
sum rosca_traced if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons 
 addstat("sample = no duplicates", 1, "control mean", `control_mean');

reg rosca_has_baseline gsra isra if rosca_duplicate==0 & rosca_traced==1;
sum rosca_has_baseline if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons
  addstat("sample = no duplicates", 1, "control mean", `control_mean');
  
reg rosca_has_baseline gsra isra if rosca_duplicate==0 & rosca_traced==1;
sum rosca_has_baseline if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons
  addstat("sample = no duplicates + traced", 1, "control mean", `control_mean');

reg rosca_has_midline gsra isra if rosca_duplicate==0 & rosca_has_baseline==1;
sum rosca_has_midline if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons
  addstat("sample = no duplicates", 1, "control mean", `control_mean');
  
reg rosca_has_midline gsra isra if rosca_duplicate==0 & rosca_has_baseline==1;
sum rosca_has_midline if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons
  addstat("sample = no duplicates + traced", 1, "control mean", `control_mean');

reg rosca_has_endline gsra isra if rosca_duplicate==0 & rosca_has_baseline==1;
sum rosca_has_endline if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons
  addstat("sample = all", 1, "control mean", `control_mean');
  
reg rosca_has_endline gsra isra if rosca_duplicate==0 & rosca_has_baseline==1;
sum rosca_has_endline if gsra==0 & isra==0 & e(sample);
local control_mean=r(mean);
quietly outreg2 using "${results}\ROSCA_compliance_attrition.out", nonote se symb(***,**,*) append bdec(2) nocons
  addstat("sample = no duplicates + traced", 1, "control mean", `control_mean');

******************;
*Web Appendix Table A2. Individual Attrition;
******************;
use "${cleaned_data_dir}\SEAR_analysis_working_merged", clear;

gen has_midline=1 if  m_buy_sr15!=.;
replace has_midline=0 if m_buy_sr15==.;

gen has_endline=1 if e_harvest2015lr!=.;
replace has_endline=0 if e_harvest2015lr==.;

gen has_baseline=1 if b_hh3_education!=.;
replace has_baseline=0 if b_hh3_education==.;

reg has_midline gsra isra if has_baseline==1, cluster(rosca_id);
sum has_midline if e(sample) & gsra==0 & isra==0 & has_baseline==1;
local control_mean=r(mean);
local control_sd=r(sd);
outreg2 using "$results\attrition.out", 
 nonote se symb(***,**,*) replace bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "# of ROSCAs", e(N_clust), "did baseline?", 1) nocons;
 
reg has_midline gsra isra if has_baseline==0, cluster(rosca_id);
sum has_midline if e(sample) & gsra==0 & isra==0 & has_baseline==0;
local control_mean=r(mean);
local control_sd=r(sd);
outreg2 using "$results\attrition.out", 
 nonote se symb(***,**,*) append bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "# of ROSCAs", e(N_clust), "did baseline?", 0) nocons; 

reg has_endline gsra isra if has_baseline==1, cluster(rosca_id);
sum has_endline if e(sample) & gsra==0 & isra==0 & has_baseline==1;
local control_mean=r(mean);
local control_sd=r(sd);
outreg2 using "$results\attrition.out", 
 nonote se symb(***,**,*) append bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "# of ROSCAs", e(N_clust), "did baseline?", 1) nocons;

reg has_endline gsra isra if has_baseline==0, cluster(rosca_id);
sum has_endline if e(sample) & gsra==0 & isra==0 & has_baseline==0;
local control_mean=r(mean);
local control_sd=r(sd);
outreg2 using "$results\attrition.out", 
 nonote se symb(***,**,*) append bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "# of ROSCAs", e(N_clust), "did baseline?", 0) nocons;

******************;
*Table 2. Summary statistics and randomization check;
******************;

*Measured at baseline;

for any 1_bed 2_sofa 3_tables 4_chairs 5_jiko 6_radio 7_tv 8_mobile 9_landline 10_wallclock 11_watches 12_sewing 14_bycicle 15_oxplough  \ num
 1500 1600 500 150 150 750 4000 2000 1500 250 190 4800 2500 5000:
 gen b_v_X=Y*b_hh12_X;
 
 for any 1_cattlelocal 2_cattlegrade 3_sheep 4_goats 5_pigs 6_chicken 7_ducks \ num 10000 28750 1400 1500 1500 300 300:
  gen b_v_X=b_hh13_X*Y;
 
egen b_durable_asset_value=rsum(b_v_1_bed-b_v_15_oxplough);
gen b_durable_asset_value_USD=b_durable_asset_value/100;
egen obs=rownonmiss(b_v_1_bed-b_v_15_oxplough);
for var b_durable_asset_value b_durable_asset_value_USD: replace X=. if obs==0;

gen b_owns_mobile=1 if b_hh12_8_mobile>0 & b_hh12_8_mobile!=.;
replace b_owns_mobile=0 if b_hh12_8_mobile==0 ;

drop obs;
egen b_animal_asset_value=rsum(b_v_1_cattle-b_v_7_ducks);
gen b_animal_asset_value_USD=b_animal_asset_value/100;
egen obs=rownonmiss(b_v_1_cattle-b_v_7_ducks);
for var b_animal_asset_value b_animal_asset_value_USD: replace X=. if obs==0;
drop obs;

gen b_age=b_hh1_age if b_hh1_age>0;

gen b_thatch_roof=1 if b_hh4_roof==1;
replace b_thatch_roof=0 if b_hh4_roof!=1 & b_hh4_roof!=.;

gen b_mud_walls=1 if  b_hh5_walls==3;
replace b_mud_walls=0 if b_hh5_walls!=3 &  b_hh5_walls!=.;

gen b_mud_floor=1 if b_hh6_floor==1;
replace b_mud_floor=0 if b_hh6_floor!=1 & b_hh6_floor!=.;

gen b_owns_land=1 if b_hh10_grouphh10_quant>0 & b_hh10_grouphh10_quant!=.;
replace b_owns_land=0 if b_hh10_grouphh10_quant==0;

gen b_acres_land=b_hh10_grouphh10_quant if b_hh10_grouphh10_unit==1;
replace b_acres_land=b_hh10_grouphh10_quant*2.47 if b_hh10_grouphh10_unit==2;


egen b_fert_qty=rsum(b_dap_15lr b_can_15lr b_npk_15lr b_urea_15lr);
egen obs=rownonmiss(b_dap_15lr b_can_15lr b_npk_15lr b_urea_15lr);
replace b_fert_qty=. if obs==0;
replace b_fert_qty=. if b_dap_15lr<0 | b_can_15lr<0 | b_npk_15lr<0 | b_urea_15lr<0;


sum b_fert_qty, d;
gen b_fert_qty_w5=b_fert_qty;
replace b_fert_qty_w5=r(p95) if b_fert_qty>r(p95) & b_fert_qty!=.;


gen b_acres_maize=b_land_15lr;
replace b_acres_land=. if b_acres_land<0;
replace b_acres_maize=. if b_acres_maize<0;

gen b_fert_per_acre_w5=b_fert_qty_w5/b_acres_maize;
sum b_fert_per_acre_w5;

replace b_exp_fert_15lr=0 if b_a3_fertilizer2015==0;
gen b_fert_USD=b_exp_fert_15lr /100;
sum b_fert_USD, d;
gen b_fert_USD_w5=b_fert_USD;
replace b_fert_USD_w5=r(p95) if b_fert_USD_w5>r(p95) & b_fert_USD!=.;

replace b_exp_seeds_15lr=0 if b_a6_hybrid2015==0;
gen b_hybrid_USD=b_exp_seeds_15lr /100;
sum b_hybrid_USD, d;
gen b_hybrid_USD_w5=b_hybrid_USD;
replace b_hybrid_USD_w5=r(p95) if b_hybrid_USD_w5>r(p95) & b_hybrid_USD!=.;

replace  b_a3_fertilizer2015=0 if b_a2_used_fertilizer==0;
replace b_a6_hybrid2015=0 if b_a5_hybrid==0;
replace b_a12_herbicide2015=0 if b_a11_herbicide==0;
replace b_a9_pesticide2015=0 if b_a8_pesticide==0;

gen b_pesticide_USD=b_exp_pest_15lr /100;
sum b_pesticide_USD, d;
gen b_pesticide_USD_w5=b_pesticide_USD;
replace b_pesticide_USD_w5=r(p95) if b_pesticide_USD_w5>r(p95) & b_pesticide_USD!=.;

gen b_herbicide_USD=b_exp_herb_15lr/100;
sum b_herbicide_USD, d;
gen b_herbicide_USD_w5=b_herbicide_USD;
replace b_herbicide_USD_w5=r(p95) if b_herbicide_USD_w5>r(p95) & b_herbicide_USD!=.;

gen b_ag_expend_USD_w5=b_hybrid_USD_w5+b_fert_USD_w5;

gen b_store_consumption=1 if  strpos(b_c3_store_reason, "1");
gen b_store_sell_high_price=1 if  strpos(b_c3_store_reason, "2") | strpos(b_c3_store_reason, "4");
gen b_store_sell_emergency=1 if  strpos(b_c3_store_reason, "3");
for var b_store_consumption b_store_sell*: replace X=0 if X==. & b_c3_store_reason!="";

for any needs_come_up spouse spouse relatives overconsume spoils spoils no_space 
 \ num 1/8: 
  cap gen b_challenge_X=. \
  replace b_challenge_X=1 if strpos(b_c5b_store_challenge, "Y");
for var b_challenge_*: replace X=0 if X==. & b_c5b_store_challenge!="";

gen b_store_gallery=1 if b_c7_store_location==1 | b_c7_store_location==2;
gen b_store_plat_table_house=1 if  b_c7_store_location==3 |  b_c7_store_location==4;
for var b_store_gallery b_store_plat_table_house: replace X=0 if X==. & b_c7_store_location!=. & b_c7_store_location!=99;


gen b_normstore_kgs= b_store_normal_lr;

sum b_normstore_kgs;
sum b_normstore_kgs, d;
gen b_normstore_kgs_w5=b_normstore_kgs;
replace b_normstore_kgs_w5=r(p95) if b_normstore_kgs_w5>r(p95) & b_normstore_kgs!=.;

gen b_maxstore_kgs=b_storage_capacity if b_storage_capacity>0;

sum b_maxstore_kgs;
sum b_maxstore_kgs, d;
gen b_maxstore_kgs_w5=b_maxstore_kgs;
replace b_maxstore_kgs_w5=r(p95) if b_maxstore_kgs_w5>r(p95) & b_maxstore_kgs!=.;


gen b_per_seasons_spoiled=b_store_season_spoiled /b_store_season_nbr;
replace b_per_seasons_spoiled=. if b_store_season_spoiled<0 | b_store_season_nbr<0;
sum b_per_seasons_spoiled;

gen b_per_lost_pergg=b_c21_store_goro_spoiled/10 if b_c21_store_goro_spoiled<=10 & b_c21_store_goro_spoiled>0;
sum b_per_lost_pergg;

gen b_per_overconsume=b_c58_overconsume_amount/100 if b_c58_overconsume_amount>0 & b_c58_overconsume_amount<100;

replace b_sell_long_yn=0 if b_sell_yn==0;


*Measured at midline, endline;
for any m_harvest_lr15 m_harvest_lr15_w5 e_harvest2015lr e_harvest2015lr_w5:
 gen v_X=(X/2.2)*(60/100);
 
 
 gen log_price=log(100-coupon);
 for num 10 20 30 40 50 60 70 80 90: gen couponX=1 if coupon==X \ replace couponX=0 if coupon!=X & coupon!=.;
 
 
 ***********************;
 *Loop through randomization check;
 ************************;
 
local baseline_vars=62;

for any 
 b_age b_hh3_education  b_thatch_roof b_mud_walls b_mud_floor b_durable_asset_value_USD b_animal_asset_value_USD b_owns_mobile
 b_hh7_bank_account b_hh8_mobile_account b_hh9_mshwari
 b_owns_land b_acres_land
 b_a3_fertilizer2015 b_fert_qty b_fert_qty_w5 b_fert_per_acre_w5 b_acres_maize b_fert_USD b_fert_USD_w5
 b_a6_hybrid2015 b_hybrid_USD b_hybrid_USD_w5
 b_a12_herbicide2015 b_herbicide_USD b_herbicide_USD_w5
 b_a9_pesticide2015 b_pesticide_USD b_pesticide_USD_w5 b_ag_expend_USD_w5
 b_store_yn  b_store_consumption b_store_sell_high_price b_store_sell_emergency
 b_store_challenge_yn  b_challenge_needs_come_up b_challenge_spouse b_challenge_relatives b_challenge_overconsume b_challenge_spoils b_challenge_no_space 
 b_store_gallery b_store_plat_table_house b_normstore_kgs b_normstore_kgs_w5 b_maxstore_kgs b_maxstore_kgs_w5 b_per_seasons_spoiled b_per_lost_pergg
 b_sell_long_yn b_buy_maize  b_c56_overconsume_yn b_per_overconsume
 
 m_harvest_lr15 m_harvest_lr15_w5 e_harvest2015lr e_harvest2015lr_w5
 v_m_harvest_lr15 v_m_harvest_lr15_w5 v_e_harvest2015lr v_e_harvest2015lr_w5 
 
 b_sell_yn \ num 1/`baseline_vars':
 global depvarY="X";
 
local i 1;
while `i' <= `baseline_vars' {;
	local append_replace="append";
	if `i'==1 {;
		local append_replace="replace";
		};
	
	reg ${depvar`i'} gsra isra log_price if (has_midline==1 | has_endline==1), cluster(rosca_id);
	test gsra=isra=0;
	local pval1=r(p);
		if `pval1'==. {; local pval1=-999; };
	

	sum ${depvar`i'} if gsra==0 & isra==0 & e(sample);
	local control_mean=r(mean);
	local control_sd=r(sd);
		if `control_mean'==. {; local control_mean=-999; };
		if `control_sd'==. {; local control_sd=-999; };
		
	quietly outreg2 using "${results}\Randomization_check.out", keep(gsra isra log_price)
	 nonote se symb(***,**,*) `append_replace' bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd',
	 "p value for ISRA=GSRA=0", `pval1', "# of ROSCAs", e(N_clust)) nocons;
	 local i = `i' + 1;
	};
	





******************;
*Web Appendix Table A2. ROSCA sum stats;
******************;
local baseline_vars=12;

gen percentage_farmers=rb_num_farmers/rb_num_members;
replace percentage_farmers=1 if percentage_farmers>1 & percentage_farmers!=.;

for any 
 rb_years_existed rb_round_length rb_num_members rb_num_farmers percentage_farmers rb_mixed_gender rb_women_only rb_table_banking 
 rb_tablebank_min_contrib_month rb_loan rb_loan_monthly_interest rb_welfare
 \ num 1/`baseline_vars':
 global depvarY="X";
 
sort rosca_id;

egen rosca_has_endline=max(has_endline), by(rosca_id);

local i 1;
while `i' <= `baseline_vars' {;
	local append_replace="append";
	if `i'==1 {;
		local append_replace="replace";
		};
	
	reg ${depvar`i'} gsra isra if rosca_id!=rosca_id[_n-1] & (rosca_has_endline==1), cluster(rosca_id);
	sum ${depvar`i'} if gsra==0 & isra==0 & e(sample);
	local control_mean=r(mean);
	local control_sd=r(sd);
	sum ${depvar`i'} if gsra==1 & e(sample);
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);
	quietly outreg2 using "${results}\ROSCA_Rand_check.out", 
	 nonote se symb(***,**,*) `append_replace' bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 
	local i = `i' + 1;
	};


******************;
*Table 3. Takeup;
******************;

replace e_made_deposit=e_ff1 if isra==1 & has_endline==1;

for any logs_GSRA_total_dep_kg logs_GSRA_total_wd_kg logs_ISRA_total_dep logs_ISRA_total_wd:
 sum X if X!=0, d \
 gen X_w1=X \
 replace X_w1=r(p99) if X>r(p99) & X!=.;

gen logs_GSRA_total_dep_kg_w1_cond=logs_GSRA_total_dep_kg_w1 if logs_made_deposit==1;
gen logs_GSRA_total_wd_kg_w1_cond=logs_GSRA_total_wd_kg_w1 if logs_made_deposit==1;

gen logs_ISRA_total_dep_w1_cond = logs_ISRA_total_dep_w1 if logs_made_deposit==1;
gen logs_ISRA_total_wd_w1_cond=logs_ISRA_total_wd_w1 if logs_made_deposit==1;

gen logs_ISRA_total_dep_w1_cond_USD=logs_ISRA_total_dep_w1_cond/100;
gen logs_ISRA_total_wd_w1_cond_USD=logs_ISRA_total_wd_w1_cond/100;
 
gen var="";
for any mean median sd N:
 gen X_gsra=. \
 gen X_isra=. \
 gen X_gsra_endline=. \
 gen X_isra_endline=. \
 gen X_gsra_midline=. \
 gen X_isra_midline=.;

local vars=8;
for any 
 logs_made_deposit logs_made_withdrawal 
 logs_GSRA_total_dep_kg_w1_cond logs_GSRA_total_wd_kg_w1_cond
 logs_ISRA_total_dep_w1_cond_USD logs_ISRA_total_wd_w1_cond_USD
 e_made_deposit e_storegsra_2015lr_w1_cond \ num 1/`vars':
 replace var="X" if _n==Y \
 sum X if gsra==1, d \

 replace mean_gsra=r(mean) if _n==Y \
 replace median_gsra=r(p50) if _n==Y \
 replace sd_gsra=r(sd) if _n==Y \
 replace N_gsra=r(N) if _n==Y \
 
 sum X if isra==1, d \
 replace mean_isra=r(mean) if _n==Y \
 replace median_isra=r(p50) if _n==Y \
 replace sd_isra=r(sd) if _n==Y \
 replace N_isra=r(N) if _n==Y \
 
 sum X if gsra==1 & has_endline==1, d \

 replace mean_gsra_endline=r(mean) if _n==Y \
 replace median_gsra_endline=r(p50) if _n==Y \
 replace sd_gsra_endline=r(sd) if _n==Y \
 replace N_gsra_endline=r(N) if _n==Y \
 
 sum X if isra==1 & has_endline==1, d \
 replace mean_isra_endline=r(mean) if _n==Y \
 replace median_isra_endline=r(p50) if _n==Y \
 replace sd_isra_endline=r(sd) if _n==Y \
 replace N_isra_endline=r(N) if _n==Y \
 
 sum X if gsra==1 & has_midline==1, d \

 replace mean_gsra_midline=r(mean) if _n==Y \
 replace median_gsra_midline=r(p50) if _n==Y \
 replace sd_gsra_midline=r(sd) if _n==Y \
 replace N_gsra_midline=r(N) if _n==Y \
 
 sum X if isra==1 & has_midline==1, d \
 replace mean_isra_midline=r(mean) if _n==Y \
 replace median_isra_midline=r(p50) if _n==Y \
 replace sd_isra_midline=r(sd) if _n==Y \
 replace N_isra_midline=r(N) if _n==Y ; 
 
 
outsheet var mean_gsra median_gsra sd_gsra N_gsra mean_isra median_isra sd_isra N_isra 
 mean_gsra_endline median_gsra_endline sd_gsra_endline N_gsra_endline mean_isra_endline median_isra_endline sd_isra_endline N_isra_endline
 mean_gsra_midline median_gsra_midline sd_gsra_midline N_gsra_midline mean_isra_midline median_isra_midline sd_isra_midline N_isra_midline
  if _n<=`vars' using "${results}\takeup", replace;
drop mean_gsra-N_isra;

		
************************************************;
*Web Appendix Table A4. Correlates of take-up;
*************************************************;

gen asinh_logs_GSRA_total_dep_kg=asinh(logs_GSRA_total_dep_kg );

gen log_animal_durable=log(b_durable_asset_value_USD +b_animal_asset_value_USD);
gen housing_index=(b_thatch_roof +b_mud_walls +b_mud_floor)/3;

for any e_harvest2015lr_w5 b_ag_expend_USD_w5: gen log_X=asinh(X);

replace b_age=b_age/10;

local vars=10;
for any b_r8_resp_gender b_age b_hh3_education log_animal_durable housing_index b_owns_mobile b_acres_maize
 b_store_challenge_yn log_e_harvest2015lr_w5 log_b_ag_expend_USD_w5 \ num 1/`vars':
 global regressorY="X" \
 gen X_m=1 if X==. \
 replace X_m=0 if X!=. \
 gen X_r=X \
 replace X_r=0 if X_m==1 ;

local varlist "b_r8_resp_gender_r b_age_r b_hh3_education_r log_animal_durable_r housing_index_r b_owns_mobile_r b_acres_maize_r 
 b_store_challenge_yn_r log_e_harvest2015lr_w5_r log_b_ag_expend_USD_w5_r";
local varlist_m "b_r8_resp_gender_m b_age_m b_hh3_education_m log_animal_durable_m housing_index_m b_owns_mobile_m b_acres_maize_m 
 b_store_challenge_yn_m log_e_harvest2015lr_w5_m log_b_ag_expend_USD_w5_m";
 
local i 1;
while `i' <= `vars' {;
	local append_replace="append";
	if `i'==1 {;
		local append_replace="replace";
		};
	
	reg logs_made_deposit ${regressor`i'} if gsra==1 & has_baseline==1, cluster(rosca_id);
	sum logs_made_deposit if e(sample);
	local mean=r(mean);
	local sd=r(sd);
	quietly outreg2 using "${results}\takeup_correlates_bivariate.out", 
	 nonote se symb(***,**,*) `append_replace' bdec(2) addstat("mean of depvar", `mean', "sd of depvar", `sd', "# of ROSCAs", e(N_clust)) nocons;

	reg asinh_logs_GSRA_total_dep_kg ${regressor`i'} if gsra==1 & has_baseline==1, cluster(rosca_id);
	sum asinh_logs_GSRA_total_dep_kg if e(sample);
	local mean=r(mean);
	local sd=r(sd);
	quietly outreg2 using "${results}\takeup_correlates_bivariate.out", 
	 nonote se symb(***,**,*) append bdec(2) addstat("mean of depvar", `mean', "sd of depvar", `sd', "# of ROSCAs", e(N_clust)) nocons;
	 
	local i = `i' + 1;
	};
 

reg logs_made_deposit `varlist' `varlist_m' if gsra==1 & has_baseline==1, cluster(rosca_id);
sum logs_made_deposit if e(sample);
local mean=r(mean);
local sd=r(sd);
quietly outreg2 using "${results}\takeup_correlates_multivariate.out", keep(`varlist') 
 nonote se symb(***,**,*) replace bdec(2) addstat("mean of depvar", `mean', "sd of depvar", `sd', "# of ROSCAs", e(N_clust)) nocons;

reg asinh_logs_GSRA_total_dep_kg `varlist' `varlist_m' if gsra==1 & has_baseline==1, cluster(rosca_id);
sum logs_made_deposit if e(sample);
local mean=r(mean);
local sd=r(sd);
quietly outreg2 using "${results}\takeup_correlates_multivariate.out", keep(`varlist') 
 nonote se symb(***,**,*) append bdec(2) addstat("mean of depvar", `mean', "sd of depvar", `sd', "# of ROSCAs", e(N_clust)) nocons;



	

******************;
*Tables 4-5. Main treatment effects;
******************;


gen m_stored_maize_lr=1 if m_totalstore_2015lr_w5>0 & m_totalstore_2015lr_w5!=.;
replace m_stored_maize_lr=0 if m_totalstore_2015lr_w5==0;

gen m_purchase_kgs=m_b28*90 if m_b28_buy_after==1 ;
replace m_purchase_kgs=m_b28 if m_b28_buy_after==2;
replace m_purchase_kgs=m_b28*2.2 if m_b28_buy_after==3;
replace m_purchase_kgs=m_b28*50 if m_b28_buy_after==-44;
replace m_purchase_kgs=0 if m_b28==0;
replace m_purchase_kgs=. if m_b28<0;

gen m_purchase_ind=0 if m_purchase_kgs==0;
replace m_purchase_ind=1 if m_purchase_kgs>0 & m_purchase_kgs!=.;

for var early_sale_ind late_sale_ind: replace X=0 if X==. & has_endline;


 for var logs_GSRA_total_dep_kg:
  sum X if X!=0, d \
  gen X_w5=X \
  replace X_w5=r(p95) if X!=. ;
 
 
 *gen lower bound of total storage variables using information from logs;
 egen lb_totalstore=rowtotal(logs_GSRA_total_dep_kg e_storeout_2015lr e_storehome_2015lr) ;
 egen lb_totalstore_w5=rowtotal(logs_GSRA_total_dep_kg_w5 e_storeout_2015lr_w5 e_storehome_2015lr_w5) ;
 egen lb_totalstore_w1=rowtotal(logs_GSRA_total_dep_kg_w1 e_storeout_2015lr_w1 e_storehome_2015lr_w1) ;
 
 egen lb_outstore=rowtotal(logs_GSRA_total_dep_kg e_storeout_2015lr ) ;
 egen lb_outstore_w5=rowtotal(logs_GSRA_total_dep_kg_w5 e_storeout_2015lr_w5 ) ;
 egen lb_outstore_w1=rowtotal(logs_GSRA_total_dep_kg_w1 e_storeout_2015lr_w1 ) ;
 
 for any lb_totalstore lb_totalstore_w1 lb_totalstore_w5 lb_outstore lb_outstore_w1 lb_outstore_w5:
 replace X=. if has_endline==0;
 
 for var lb_totalstore  lb_outstore:
 sum X, d \
 gen w1_X=X \
 gen w5_X=X \
 replace w1_X=r(p99) if X>r(p99) & X!=. \
 replace w5_X=r(p95) if X>r(p95) & X!=.;
 
gen price=(100-coupon)/100;

local depvars 24;

for num 1/`depvars' \ any
 m_stored_maize_lr m_totalstore_2015lr_w5 m_storeout_lr15_w5 m_storehome_lr15_w5
 e_stored_maize_lr e_totalstore_2015lr_w5 e_storeout_plusgsra_2015lr_w5 e_storeout_2015lr_w5 e_storehome_2015lr_w5 e_storegsra_2015lr_w5
 e_D_sold_sales_module e_total_sales_sales_module_w5 e_total_revenue_sales_module_w5 e_log_ave_price_sales_module_kg e_ave_price_sales_module_kg 
 e_weighted_days_sales_module m_purchase_kgs m_purchase_ind  lb_totalstore_w5 lb_outstore_w5 w5_lb_totalstore w5_lb_outstore early_sale_ind late_sale_ind:

 global depvarX="Y";

for var m_harvest_lr15_w5 e_harvest2015lr_w5: 
 gen X_1k=X/1000 \ gen X_m=1 if X==. \ replace X_m=0 if X!=. \ 
 gen X_r=X \ replace X_r=0 if X_m==1 \ gen X_1k_r=X_1k \ replace X_1k_r=0 if X_m==1;

for num 1: global harvest_controlX "m_harvest_lr15_w5_1k_r m_harvest_lr15_w5_m";
for num 2/4 17 18: global harvest_controlX "m_harvest_lr15_w5_r m_harvest_lr15_w5_m";
for num 5 11 14 15 23 24: global harvest_controlX "e_harvest2015lr_w5_1k_r e_harvest2015lr_w5_m";
for num 6/10 12 13 16 19/22: global harvest_controlX "e_harvest2015lr_w5_r e_harvest2015lr_w5_m";

for any b_sell_yn b_per_seasons_spoiled b_hh7_bank_account b_fert_qty b_buy_maize 
: gen X_m=0 if X!=. \ replace X_m=1 if X==. \ gen X_r=X \ replace X_r=0 if X==.;

global control_vars="b_sell_yn_r b_per_seasons_spoiled_r b_buy_maize_r b_hh7_bank_account_r b_owns_mobile_r b_fert_qty_r 
 b_sell_yn_m b_per_seasons_spoiled_m b_buy_maize_m b_hh7_bank_account_m b_owns_mobile_m b_fert_qty_m";

*Make the total storage winsorized the sum of the others;
replace e_totalstore_2015lr_w5=e_storeout_plusgsra_2015lr_w5+ e_storehome_2015lr_w5;
replace e_totalstore_2015lr_w1=e_storeout_plusgsra_2015lr_w1+ e_storehome_2015lr_w1;

local i 1;
while `i' <= `depvars' {;
		
	local append_replace="append";
	if `i'==1 {;
		local append_replace="replace";
		};
			
	*A. ITT: No harvest control;
	reg ${depvar`i'} gsra isra ${control_vars} log_price, cluster(rosca_id);
	sum ${depvar`i'} if e(sample) & gsra==0 & isra==0 ;
	local control_mean=r(mean);
	local control_sd=r(sd);
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; };
	sum ${depvar`i'} if e(sample) & gsra==1;
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);	
	outreg2 using "$results\Treatment_Effects_ITT.out", keep(gsra isra log_price)
	 nonote se symb(***,**,*) `append_replace' bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 

	*B. ITT: Harvest control;
	reg ${depvar`i'} gsra isra log_price ${harvest_control`i'} ${control_vars} , cluster(rosca_id);
	sum ${depvar`i'} if e(sample) & gsra==0 & isra==0;
	local control_mean=r(mean);
	local control_sd=r(sd);
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; };
	sum ${depvar`i'} if e(sample) & gsra==1;
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);	
	outreg2 using "$results\Treatment_Effects_ITT.out", keep(gsra isra log_price ${harvest_control`i'})
	 nonote se symb(***,**,*) append bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 
	 
	local i = `i' + 1;
	};
		
*Appendix: with no or 5% winsorizing;
local appendix_vars=20;

for num 1/`appendix_vars' \ any
 m_totalstore_2015lr_w1 m_storeout_lr15_w1 m_storehome_lr15_w1
 e_totalstore_2015lr_w1 e_storeout_plusgsra_2015lr_w1 e_storeout_2015lr_w1 e_storehome_2015lr_w1 e_storegsra_2015lr_w1
 e_total_sales_sales_module_w1 e_total_revenue_sales_module_w1 
 
 m_totalstore_2015lr m_storeout_lr15 m_storehome_lr15
 e_totalstore_2015lr e_storeout_plusgsra_2015lr e_storeout_2015lr e_storehome_2015lr e_storegsra_2015lr
 e_total_sales_sales_module e_total_revenue_sales_module:
 global depvarX="Y";


for num 1/3 11/13: global harvest_controlX="m_harvest_lr15_w5_r m_harvest_lr15_w5_m";
for num 4/10 14/20: global harvest_controlX="e_harvest2015lr_w5_r e_harvest2015lr_w5_m";

local i 1;
while `i' <= `appendix_vars' {;
		
	local append_replace="append";
	if `i'==1 {;
		local append_replace="replace";
		};
			
	*A. No harvest control;
	xi: reg ${depvar`i'} gsra isra ${control_vars} log_price, cluster(rosca_id);
	sum ${depvar`i'} if e(sample) & gsra==0 & isra==0;
	local control_mean=r(mean);
	local control_sd=r(sd);
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; };
	sum ${depvar`i'} if e(sample) & gsra==1;
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);	
	outreg2  using "$results\Appendix_Treatment_Effects_ITT.out", keep(gsra isra log_price)
	 nonote se symb(***,**,*) `append_replace' bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 
	*B. Harvest control;
	xi: reg ${depvar`i'} gsra isra log_price ${harvest_control`i'} ${control_vars} , cluster(rosca_id);
	sum ${depvar`i'} if e(sample) & gsra==0 & isra==0 & coupon==10;
	local control_mean=r(mean);
	local control_sd=r(sd);
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; };
	sum ${depvar`i'} if e(sample) & gsra==1;
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);	
	outreg2 gsra isra log_price using "$results\Appendix_Treatment_Effects_ITT.out", keep(gsra isra log_price ${harvest_control`i'})
	 nonote se symb(***,**,*) append bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 
	 
	local i = `i' + 1;
	};

******************;
*Table 6. Other outcomes;
******************;
local depvars 16;

gen e_used_fert=e_c3;
gen e_fert_expend=e_c5;
gen e_used_hybrid=e_use_hybrid_16lr;
gen e_hybrid_expend=e_hybrid_16lr_1;
for var e_c4_DAP- e_c4_other: replace X=. if X == -99;
egen e_fert_quant=rowtotal(e_c4_DAP- e_c4_other), missing;

replace e_fert_expend=0 if e_used_fert==0;
replace e_hybrid_expend=0 if e_used_hybrid==0;
replace e_fert_quant=0 if e_used_fert==0;

for any e_fert_expend e_hybrid_expend e_fert_quant:
 sum X if X!=0, d \
 gen X_w1=X \
 gen X_w5=X \
 replace X_w1=r(p99) if X>r(p99) & X!=. \
 replace X_w5=r(p95) if X>r(p95) & X!=.;

gen e_total_ag_expend=e_fert_expend+e_hybrid_expend;
gen e_total_ag_expend_w1=e_fert_expend_w1+e_hybrid_expend_w1;
gen e_total_ag_expend_w5=e_fert_expend_w5+e_hybrid_expend_w5;

*USD;
for var e_total_ag_expend*: replace X=X/100;

gen e_reduced_food_intake= e_cant_afford_maize;
gen e_kid_missed_school_fees=e_skip_school;
gen e_shock_didnt_get_enough_cash=e_money_unanticipate;
gen e_reduced_food_afford_inputs=e_16lr_less_planting;

gen e_ran_out_of_maize=e_cant_afford_maize;

cap gen log_price=log(100-coupon);

gen log_e_total_ag_expend=log(e_total_ag_expend);
gen log_e_total_ag_expend_w1=log(e_total_ag_expend_w1);
gen log_e_total_ag_expend_w5=log(e_total_ag_expend_w5);

gen log_redeemed_USD=log(r_redeemed_market_value_USD);


local depvars=21;
for num 1/`depvars' \ any
 e_used_fert e_used_hybrid e_total_ag_expend e_total_ag_expend_w1 e_total_ag_expend_w5 
 e_reduced_food_intake e_kid_missed_school_fees e_shock_didnt_get_enough_cash e_reduced_food_afford_inputs e_ran_out_of_maize r_redeemed_coupon r_redeemed_market_value_USD
 e_fert_expend e_fert_expend_w1 e_fert_expend_w5 e_fert_quant e_fert_quant_w1 e_fert_quant_w5 e_hybrid_expend e_hybrid_expend_w1 e_hybrid_expend_w5:
 global depvarX="Y";


local i 1;
while `i' <= `depvars' {;
		
	local append_replace="append";
	if `i'==1 {;
		local append_replace="replace";
		};
			
	*A. No controls;
	xi: reg ${depvar`i'} gsra isra ${control_vars} log_price, cluster(rosca_id);
	sum ${depvar`i'} if e(sample) & gsra==0 & isra==0;
	local control_mean=r(mean);
	local control_sd=r(sd);
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; };
	sum ${depvar`i'} if e(sample) & gsra==1;
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);	
	outreg2 using "$results\Treatment_Effects_Other_Outcomes_ITT.out", keep(gsra isra log_price)
	 nonote se symb(***,**,*) `append_replace' bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 
	 *B. Harvest control;
	xi: reg ${depvar`i'} gsra isra log_price e_harvest2015lr_w5_1k_r e_harvest2015lr_w5_m ${control_vars} , cluster(rosca_id);
	sum ${depvar`i'} if e(sample) & gsra==0 & isra==0 ;
	local control_mean=r(mean);
	local control_sd=r(sd);
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; };
	sum ${depvar`i'} if e(sample) & gsra==1;
	local gsra_mean=r(mean);
	local gsra_sd=r(sd);	
	outreg2 using "$results\Treatment_Effects_Other_Outcomes_ITT.out", keep(gsra isra log_price e_harvest2015lr_w5_1k_r e_harvest2015lr_w5_m )
	 nonote se symb(***,**,*) append bdec(2) addstat("control mean", `control_mean', "control sd", `control_sd', "gsra mean", `gsra_mean', "gsra sd", `gsra_sd', 
	 "# of ROSCAs", e(N_clust)) nocons;
	 
	 
	local i = `i' + 1;
	};
	

******************;
*Figure 4. Demand curve;
******************;
	
gen group=1 if isra==0 & gsra==0;
replace group=2 if isra==1;
replace group=3 if gsra==1;

local label1 "control";
local label2 "ISRA";
local label3 "GSRA";

*Redemption;
gen price_to_graph=.;
for num 1/9 \ num 10 20 30 40 50 60 70 80 90: replace price_to_graph=100-Y if _n==X;

local i 1;
while `i' <= 3 {;
	reg r_redeemed_coupon coupon10-coupon90 if group==`i', nocons cluster(rosca_id);
	mat beta=e(b);
	mat var=e(V);
	gen coefficient_`label`i''=.;
	gen SE_`label`i''=.;
	local j 1;
	while `j' <= 9 {;
		replace coefficient_`label`i''=beta[1,`j'] if _n==`j';
		replace SE_`label`i''=var[`j',`j']^.5 if _n==`j';
		local j = `j' + 1;
		};
	gen lower_`label`i''=coefficient_`label`i''-1.96*SE_`label`i'';
	gen upper_`label`i''=coefficient_`label`i''+1.96*SE_`label`i'';
	local i = `i' + 1;
	};
		

*Figure with CIs;
twoway 
 (scatter coefficient_control price_to_graph, connect(l) msymbol(o)) 
 (rcapsym lower_control upper_control price_to_graph, msymbol(i))
 (scatter coefficient_GSRA price_to_graph, connect(l) lpattern(-) msymbol(T)) 
 (rcapsym lower_GSRA upper_GSRA price_to_graph, msymbol(i))
 (scatter coefficient_ISRA price_to_graph, connect(l) lpattern(.) msymbol(x))
 (rcapsym lower_ISRA upper_ISRA price_to_graph, msymbol(i));
 
*Figure without CIs;
twoway 
 (scatter coefficient_control price_to_graph, connect(l) msymbol(o)) 
 (scatter coefficient_GSRA price_to_graph, connect(l) lpattern(-) msymbol(T)) 
 (scatter coefficient_ISRA price_to_graph, connect(l) lpattern(.) msymbol(x)),
 xlabel(0 (10) 90) ylabel(0 (.1) 1) xtitle("Price (% of retail)") ytitle("Percentage redeeming")
 title("Extensive margin", size(medium)) saving("${results}/demand_extensive_margin", replace)
 legend(order(1 "Control" 2 "GSRA" 3 "ISRA"));
 
*Quantities redeemed;

local i 1;
while `i' <= 3 {;
	reg r_redeemed_market_value_USD coupon10-coupon90 if group==`i', nocons cluster(rosca_id);
	mat beta=e(b);
	mat var=e(V);
	replace coefficient_`label`i''=.;
	replace SE_`label`i''=.;
	local j 1;
	while `j' <= 9 {;
		replace coefficient_`label`i''=beta[1,`j'] if _n==`j';
		replace SE_`label`i''=var[`j',`j']^.5 if _n==`j';
		local j = `j' + 1;
		};
	replace lower_`label`i''=coefficient_`label`i''-1.96*SE_`label`i'';
	replace upper_`label`i''=coefficient_`label`i''+1.96*SE_`label`i'';
	local i = `i' + 1;
	};
		

*Figure with CIs;
twoway 
 (scatter coefficient_control price_to_graph, connect(l) msymbol(o)) 
 (rcapsym lower_control upper_control price_to_graph, msymbol(i))
 (scatter coefficient_GSRA price_to_graph, connect(l) lpattern(-) msymbol(T)) 
 (rcapsym lower_GSRA upper_GSRA price_to_graph, msymbol(i))
 (scatter coefficient_ISRA price_to_graph, connect(l) lpattern(.) msymbol(x))
 (rcapsym lower_ISRA upper_ISRA price_to_graph, msymbol(i));
 
*Figure without CIs;
twoway 
 (scatter coefficient_control price_to_graph, connect(l) msymbol(o)) 
 (scatter coefficient_GSRA price_to_graph, connect(l) lpattern(-) msymbol(T)) 
 (scatter coefficient_ISRA price_to_graph, connect(l) lpattern(.) msymbol(x)),
 xlabel(0 (10) 90) ylabel(0 (5) 30) xtitle("Price (% of retail)") ytitle("Market Value of Inputs Purchased with Coupon")
 title("Total market value of inputs purchased with coupon (USD)", size(medium)) saving("${results}/demand_extensive_margin", replace)
 legend(order(1 "Control" 2 "GSRA" 3 "ISRA"));
 

******************;
*Table 7. Pathways;
******************;

gen m_b13_gsra_effective_share_costs=1 if strpos(m_b13_why_gsra, "1");
gen m_b13_gsra_effective_less_spoil=1 if strpos(m_b13_why_gsra, "2");
gen m_b13_gsra_effective_less_cons=1 if strpos(m_b13_why_gsra, "3");
gen m_b13_gsra_effective_gave_less=1 if strpos(m_b13_why_gsra, "4") | strpos(m_b13_why_gsra, "5");
gen m_b13_gsra_effective_save_input=1 if strpos(m_b13_why_gsra, "6");
for var m_b13_gsra_effective_share_costs -m_b13_gsra_effective_save_input: replace X=0 if X==. & m_b13_why_gsra!="";
sum m_b13_gsra*;

gen m_b14_agree=1 if m_b14_maize<=2;
replace m_b14_agree=0 if m_b14_maize>2 & m_b14_maize<6;
sum m_b14_agree;

gen m_b15_agree=1 if m_b15_pre<=2;
replace m_b15_agree=0 if m_b15_pre>2 & m_b15_pre<6;
sum m_b15_agree;

gen m_b17_agree_give=1 if m_b17_home<=2;
replace m_b17_agree_give=0 if m_b17_home>2 & m_b17_home<6;

gen m_b18_agree_give_gsra=1 if m_gsra_2b18_gsramaize<=2;
replace m_b18_agree_give=0 if m_gsra_2b18_gsramaize>2 & m_gsra_2b18_gsramaize<6;
sum m_b17_agree m_b18_agree if gsra==1;

gen m_b17_agree_give_GSRA_only=m_b17_agree_give if gsra==1;

gen m_b21_gave_less_less_ask=1 if m_gsra_2b21_gaveless==2;
gen m_b21_gave_less_easier_no=1 if m_gsra_2b21_gaveless==3;
for var m_b21_gave_less*: replace X=0 if X==. & m_gsra_2b21_gaveless!=. & m_gsra_2b21_gaveless>0;

gen m_b23_reciprocal_agree=1 if m_b23_refuse<=2;
replace m_b23_reciprocal_agree=0 if m_b23_refuse>2 & m_b23_refuse<6;
sum m_b23_reciprocal_agree;

*Endline losses;
gen e_per_maize_lost_home=e_phl_home/10 if e_phl_home>=0 & e_phl_home<=10;
sum e_per_maize_lost_home;

gen e_lost_maize_home=1 if e_per_maize_lost_home>0 & e_per_maize_lost_home!=.;
replace e_lost_maize_home=0 if e_per_maize_lost_home==0 ;

gen e_per_maize_overspent_home=e_early_cons_qty/10 if e_early_cons_qty>=0 & e_early_cons_qty<=10;
replace e_per_maize_overspent_home=0 if e_early_cons==0;

gen e_overspent_maize_home=e_early_cons;

sum e_per_maize_lost_home e_per_maize_overspent_home;

gen e_gsra_lost_maize=e_gsra_spoil if e_gsra_spoil==1;
replace e_gsra_lost_maize=0 if e_gsra_spoil==2;

gen e_gsra_lost_maize_qty=e_ee_0rosca_adopte22_grou*2.2 if e_v492==3;
replace e_gsra_lost_maize_qty=e_ee_0rosca_adopte22_grou*90 if e_v492==1;
replace e_gsra_lost_maize_qty=0 if e_gsra_lost_maize==0;

gen e_gsra_lost_maize_qty_COND=e_gsra_lost_maize_qty if e_gsra_lost_maize_qty!=0;

gen per_lost_gsra=e_gsra_lost_maize_qty/e_storegsra_2015lr;
sum per_lost_gsra;
*some unit problems;

for any e_gsra_lost_maize_qty e_gsra_lost_maize_qty_COND per_lost_gsra:
 replace X=. if per_lost_gsra>1;

gen e_per_maize_lost_home_COND=e_per_maize_lost_home if e_lost_maize_home==1;
gen e_per_maize_overspent_home_COND=e_per_maize_overspent_home if e_overspent_maize_home==1;

 
sum per_lost_gsra;


*rename m_gsra_2b18_gsramaize m_b18_agree_give_gsra;
rename m_gsra_2b19_gaveless m_b19;

gen e_isra_helped= e_fisra_adoptf24;
gen e_isra_continue=e_ff3;


local pathways=29;
for any m_b11_gsra_help m_b13_gsra_effective_share_costs m_b13_gsra_effective_less_spoil m_b13_gsra_effective_less_cons m_b13_gsra_effective_gave_less m_b13_gsra_effective_save_input 
 m_b15_agree m_b18_agree_give_gsra m_b17_agree_give_GSRA_only m_b19 m_b21_gave_less_less_ask m_b21_gave_less_easier_no  
 e_gsra_lost_maize e_gsra_lost_maize_qty e_gsra_lost_maize_qty_COND per_lost_gsra e_adopt2016
 m_b14_agree m_b17_agree_give m_b23_reciprocal_agree e_lost_maize_home e_per_maize_lost_home 
 e_per_maize_lost_home_COND e_overspent_maize_home e_per_maize_overspent_home e_per_maize_overspent_home_COND  
 e_gsra_help e_isra_helped e_isra_continue \ num 1/`pathways': global pathwayY="X";

 

cap gen log_price=log(100-coupon);


local i 1;
while `i' <= `pathways' {;

	local append_replace="append";
	if `i'==1 {; local append_replace="replace"; };
	
	sum ${pathway`i'} if gsra==0 & isra==0;
	local control_mean=r(mean) ;
	local control_sd=r(sd) ;
	local control_N=r(N) ;
	if `control_mean'==. {; local control_mean=-999; local control_sd=-999; local control_N=-999;};
 
	sum ${pathway`i'} if isra==1;
	local ISRA_mean=r(mean) ;
	local ISRA_sd=r(sd) ;
	local ISRA_N=r(N) ;
	if `ISRA_mean'==. {; local ISRA_mean=-999; local ISRA_sd=-999; local ISRA_N=-999;};

	sum ${pathway`i'} if gsra==1;
	local GSRA_mean=r(mean) ;
	local GSRA_sd=r(sd) ;
	local GSRA_N=r(N) ;
	if `GSRA_mean'==. {; local GSRA_mean=-999; local GSRA_sd=-999; local GSRA_N=-999;};
	
	reg ${pathway`i'} gsra isra log_price, cluster(rosca_id);
	outreg2 using "$results\pathways_regressions.out", keep(gsra isra log_price)
	 nonote se symb(***,**,*) `append_replace' bdec(2) 
	  addstat("control mean", `control_mean', "control sd", `control_sd', "control N", `control_N', 
	  "GSRA mean", `GSRA_mean', "GSRA sd", `GSRA_sd', "GSRA N", `GSRA_N',
	  "ISRA mean", `ISRA_mean', "ISRA sd", `ISRA_sd', "ISRA N", `ISRA_N',
	  "# of ROSCAs", e(N_clust)) nocons;
	local i = `i' + 1;
	};

*ROSCA level;
sort rosca_id;
sum er_continue if rosca_id!=rosca_id[_n-1] ;


************************************************;
*Web Appendix Figure A5. Quantile regressions;
************************************************;

gen treatment_effect_gsra=.;
gen SE_gsra=.;
gen treatment_effect_isra=.;
gen SE_isra=.;
gen percentile=_n*10/100;


global control_vars="b_sell_yn_r b_per_seasons_spoiled_r b_buy_maize_r b_hh7_bank_account_r b_owns_mobile_r b_fert_qty_r 
 b_sell_yn_m b_per_seasons_spoiled_m b_buy_maize_m b_hh7_bank_account_m b_owns_mobile_m b_fert_qty_m e_harvest2015lr_w5_r e_harvest2015lr_w5_m";

 
local depvar1 "e_total_sales_sales_module_w5";
local depvar2 "e_totalstore_2015lr_w5";
local label1 "Maize Sales";
local label2 "Total Quantity of Maize Stored";
 
local k 1;
while `k' <= 2 {;

	local i 1;
	while `i' <= 9 {;
		local j=10*`i'/100;
		quietly qreg `depvar`k'' gsra isra $control_vars, quantile(`j');
		mat beta=e(b);
		mat var=e(V);
		quietly replace treatment_effect_gsra=beta[1,1] if _n==`i';
		quietly replace SE_gsra=var[1,1]^.5 if _n==`i';
		quietly replace treatment_effect_isra=beta[1,2] if _n==`i';
		quietly replace SE_isra=var[2,2]^.5 if _n==`i';
		di `i';
		local i = `i' + 1;
		};
		

for any gsra isra:
 gen lower_X=treatment_effect_X-1.96*SE_X \
 gen upper_X=treatment_effect_X+1.96*SE_X;

twoway 
 (scatter treatment_effect_gsra percentile if _n<=9, connect(l) msymbol(o)) 
 (rcapsym lower_gsra upper_gsra percentile if _n<=9, msymbol(i)),
 xlabel(0 (0.1) 1) ylabel(#7)
 xtitle("Percentile of Sales") ytitle("Estimated Treatment Effect")
 legend(order(1 "Estimated Treatment Effect - GSRA" 2 "95% CI"))
 title("Quantile Treatment Effect for `label`k''", size(medium)) 
 saving("${results}\QTE_post-treat_Sales_GSRA_`k'", replace);

 twoway 
 (scatter treatment_effect_isra percentile if _n<=9, connect(l) msymbol(o)) 
 (rcapsym lower_gsra upper_isra percentile if _n<=9, msymbol(i)),
 xlabel(0 (0.1) 1) ylabel(#7)
 xtitle("Percentile of Sales") ytitle("Estimated Treatment Effect")
 legend(order(1 "Estimated Treatment Effect - ISRA" 2 "95% CI"))
 title("Quantile Treatment Effect for `label`k''", size(medium)) 
 saving("${results}\QTE_post-treat_Sales_ISRA_`k'", replace);
 
 cap drop lower_* upper_*;

local k = `k' + 1;
};
*/; 


******************;
*Table 1. Secondary data;
******************;

use "${cleaned_data_dir}\prices_Kisumu", replace;
sort dataset year month;
bys dataset year: egen troughprice=min(price) ;
bys dataset year: egen peakprice=max(price) ;
bys dataset year: keep if _n==_N;
drop month price;

gen peak_trough_increase=peakprice/troughprice;

reshape wide peak_trough_increase peakprice troughprice, i(year) j(dataset) string;

egen avg_increase = rowmean(peak_trough_increase*);

outsheet using "${results}\Kisumu_prices.out", replace;

